@@ -108,6 +108,9 @@ sub _compile {
     elsif ($css =~ /\G:([\w\-]+)(?:\(((?:\([^)]+\)|[^)])+)\))?/gcs) {
       my ($name, $args) = (lc $1, $2);
 
+      # ":text" (raw text)
+      $args = [$args =~ m!^/(.+)/$! ? qr/$1/ : qr/\Q$args\E/i] if $name eq 'text';
+
       # ":is" and ":not" (contains more selectors)
       $args = _compile($args, %ns) if $name eq 'has' || $name eq 'is' || $name eq 'not';
 
@@ -137,8 +140,6 @@ sub _compile {
   return $group;
 }
 
-sub _empty { $_[0][0] eq 'comment' || $_[0][0] eq 'pi' }
-
 sub _equation {
   return [0, 0] unless my $equation = shift;
 
@@ -214,11 +215,15 @@ sub _pc {
   return !!_select(1, $current, $args) if $class eq 'has';
 
   # ":empty"
-  return !grep { !_empty($_) } @$current[4 .. $#$current] if $class eq 'empty';
+  return !grep { !($_->[0] eq 'comment' || $_->[0] eq 'pi') } @$current[4 .. $#$current] if $class eq 'empty';
 
   # ":root"
   return $current->[3] && $current->[3][0] eq 'root' if $class eq 'root';
 
+  # ":text"
+  return grep { ($_->[0] eq 'text' || $_->[0] eq 'raw') && $_->[1] =~ $args->[0] } @$current[4 .. $#$current]
+    if $class eq 'text';
+
   # ":any-link", ":link" and ":visited"
   if ($class eq 'any-link' || $class eq 'link' || $class eq 'visited') {
     return undef unless $current->[0] eq 'tag' && exists $current->[2]{href};
@@ -635,6 +640,23 @@ This selector is part of L<Selectors Level 4|https://dev.w3.org/csswg/selectors-
 Also be aware that this feature is currently marked C<at-risk>, so there is a high chance that it will get removed
 completely.
 
+=head2 E:text(string_or_regex)
+
+An C<E> element containing text content that substring matches C<string_or_regex> case-insensitively or that regex
+matches C<string_or_regex>. For regular expressions use the format C<:text(/.../)>. Note that this selector is
+B<EXPERIMENTAL> and might change without warning!
+
+  # Substring match
+  my $login = $css->select(':text(Log in)');
+
+  # Regex match
+  my $login = $css->select(':text(/Log ?in/)');
+
+  # Regex match (case-insensitive)
+  my $login = $css->select(':text(/(?i:Log ?in)/)');
+
+This is a custom selector for L<Mojo::DOM> and not part of any spec.
+
 =head2 A|E
 
 An C<E> element that belongs to the namespace alias C<A> from L<CSS Namespaces Module Level
